@@ -110,14 +110,15 @@ class EmailManager(threading.Thread):
                     self.server.idle()
 
             except (socket.gaierror, socket.timeout,
-                    IMAPClientAbortError, IMAPClientError) as error:
+                    IMAPClientAbortError, IMAPClientError,
+                    BrokenPipeError) as error:
                 logger.warning(error)
                 time.sleep(10)
                 self.server = None
                 continue
 
             except Exception as error:
-                logger.error(error)
+                logger.error(f"{type(error)} - {error}")
                 time.sleep(600)
                 self.server = None
                 continue
